Learn R Programming

dgmb (version 1.0)

XexXen: Simulated data

Description

A function to create an array with simulated data.

Usage

XexXen(N, n, ind.ex, ind.en, x.ex, x.en)

Arguments

N
The number of data sets.
n
The sample size of each data set.
ind.ex
The total number of manifest variables of exogenous constructs.
ind.en
The total number of manifest variables of endogenous constructs.
x.ex
An array with N matrices of dimension n times ind.ex with the scores of manifest variables.
x.en
An array with N matrices of dimension n times ind.en with the scores of manifest variables.

Value

  • xAn array with N matrices of dimension n times ind.ex + ind.en with the scores of manifest variables.

Examples

Run this code
N <- 500
n <- 250
x <- XexXen(N,n,intpar$ind.ex,intpar$ind.en,xex$x.ex,xen$x.en)
attributes(x)
x <- x$x

Run the code above in your browser using DataLab