Learn R Programming

dgmb (version 1.0)

ErrEnLV: Calculating disturbance terms

Description

A function to calculate the disturbance terms of the endogenous construct.

Usage

ErrEnLV(N, n, ben, bet, y.ex.cor)

Arguments

N
The number of data sets.
n
The sample size of each data set.
ben
The number of endogenous constructs per model (default = 1).
bet
A vector with the true values of path coefficients (linear, nonlinear and interaction effects).
y.ex.cor
An array with N matrices of dimension ncol(y.ex)+ncol(a.nle)+ ncol(a.ie) times ncol(y.ex)+ncol(a.nle)+ncol(a.ie) with the correlations between exogenous constructs (linear, nonlinear, and interaction ef

Value

  • A list with the following components:
  • std.errorA vector with the standard deviation of disturbance terms of the endogenous constructs. The vector length is equal to the number of replications.
  • elvAn array with N matrices of dimension n times ben with the disturbance terms of the endogenous constructs.

See Also

EnLVs, EnMVs, XexXen

Examples

Run this code
N <- 500
n <- 250
err <- ErrEnLV(N,n,intpar$ben,path.coef,yexcor$y.ex.cor)
attributes(err)

Run the code above in your browser using DataLab